@@ -31,6 +31,23 @@ class Content:
     draft = False
     data = None
 
+    def __init__(self, src_dir='', src_file='', data={}, content=''):
+	""" The src_dir argument is the path to the filename without the
+	original source. """
+	if 'template' not in data:
+	    msg = '"template" is required in "%s"' % src_file
+	    raise ContentDataAttributeError(msg)
+
+	self.template = data.get('template')
+	self.src_file = src_file
+	self.src_dir = src_dir
+	self.data = data
+	self.process_filename()
+	self.content = markdown.markdown(content)
+	if 'draft' in data and data['draft'] is True:
+	    self.draft = True
+	self.permalink = self.set_permalink()
+
     def tojinja2(self):
         """ Prepare attributes to be passed to a Jinja template """
         filterlam = lambda (k, v): k not in ['data', 'src_dir', 'src_file']
@@ -73,25 +90,10 @@ class Post(Content):
     publish_date = None
 
     def __init__(self, src_dir='', src_file='', data={}, content=''):
-        """
-        The src_dir argument is the path to the filename without the original
-        source. For example /my/site/content/blog/2012-12-12-a-file.md would
-        be blog, and /my/site/content/blog/thing/2012-12-12-a-file.md would be
-        blog/thing
-        """
-        if 'template' not in data:
-            msg = '"template" is required in "%s"' % src_file
-            raise ContentDataAttributeError(msg)
-
-        self.template = data.get('template')
-        self.src_dir = self.category = src_dir
-        self.src_file = src_file
-        self.data = data
-        self.process_filename()
-        self.content = markdown.markdown(content)
-        if 'draft' in data and data['draft'] is True:
-            self.draft = True
-        self.permalink = self.set_permalink()
+	""" The src_dir argument is the path to the filename without the
+	original source. """
+	Content.__init__(self, src_dir, src_file, data, content)
+	self.category = self.src_dir
 
     def process_filename(self):
         """ Get publish_date, slug and dst filename for a post """
@@ -120,24 +122,6 @@ class Page(Content):
     draft = False
     data = None
 
-    def __init__(self, src_dir='', src_file='', data={}, content=''):
-        """
-        The src_dir argument is the path to the filename without the original
-        source.
-        """
-        if 'template' not in data:
-            msg = '"template" is required in "%s"' % src_file
-            raise ContentDataAttributeError(msg)
-
-        self.template = data.get('template')
-        self.src_file = src_file
-        self.src_dir = src_dir
-        self.data = data
-        self.process_filename()
-        self.content = markdown.markdown(content)
-        if 'draft' in data and data['draft'] is True:
-            self.draft = True
-
     def process_filename(self):
         """ slug and dst filename for a post """
         self.slug, self.ext = os.path.splitext(self.src_file)
@@ -172,6 +156,10 @@ class Posts:
         return Posts(sorted(self.result, key=key, reverse=reverse))
 
     def limit(self, max):
-        if len(self.result) < 1:
-            return Posts([])
-        return Posts([self.result[0]])
+	if len(self.result) < 1:
+	    return Posts([])
+	return Posts(self.result[0:max])
+
+    def nodraft(self):
+	filter_ = lambda x: x.draft is False
+	return Posts(filter(filter_, self.result))
